@@ -95,7 +95,11 @@ m_CFHostClientCallBack(CFHostRef host, CFHostInfoType typeInfo, const CFStreamEr
 		return;
 	}
 
+#ifdef __LP64__
+	PyObject* py_error = PyObjC_ObjCToPython("{_CFStreamError=qi}", (void*)error);
+#else
 	PyObject* py_error = PyObjC_ObjCToPython("{_CFStreamError=ii}", (void*)error);
+#endif
 	if (py_error == NULL) {
 		Py_DECREF(py_host);
 		Py_DECREF(py_info);
@@ -299,7 +303,7 @@ m_CFHostSetClient(PyObject* mod __attribute__((__unused__)),
 
 
 
-static PyMethodDef m_methods[] = {
+static PyMethodDef mod_methods[] = {
 #if PyObjC_BUILD_RELEASE >= 1005
 	{
 		"CFNetworkExecuteProxyAutoConfigurationScript",
@@ -325,20 +329,31 @@ static PyMethodDef m_methods[] = {
 	{ 0, 0, 0, }
 };
 
-void init_manual(void);
-void init_manual(void)
+PyObjC_MODULE_INIT(_manual)
 {
-	PyObject* m = Py_InitModule4("_manual", m_methods,
-		NULL, NULL, PYTHON_API_VERSION);
+	PyObject* m;
 
-        if (PyObjC_ImportAPI(m) < 0) { return; }
+	m = PyObjC_MODULE_CREATE(_manual)
+	if (!m) {
+		PyObjC_INITERROR();
+	}
+
+        if (PyObjC_ImportAPI(m) < 0) { 
+		PyObjC_INITERROR();
+	}
 
 #if PyObjC_BUILD_RELEASE >= 1005
 	if (CFNetworkExecuteProxyAutoConfigurationScript == NULL) {
-		PyDict_DelItemString(m, "CFNetworkExecuteProxyAutoConfigurationScript");
+		if (PyDict_DelItemString(m, "CFNetworkExecuteProxyAutoConfigurationScript") < 0) {
+			PyObjC_INITERROR();
+		}
 	}
 	if (CFNetworkExecuteProxyAutoConfigurationURL == NULL) {
-		PyDict_DelItemString(m, "CFNetworkExecuteProxyAutoConfigurationURL");
+		if (PyDict_DelItemString(m, "CFNetworkExecuteProxyAutoConfigurationURL") < 0) {
+			PyObjC_INITERROR();
+		}
 	}
 #endif
+
+	PyObjC_INITDONE();
 }
